summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-aggregator.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2022-07-30 22:54:21 +0200
committerChristian Grothoff <christian@grothoff.org>2022-07-30 22:54:21 +0200
commit150917694a4dc3709319fc9586e502eb4b05151f (patch)
tree2b4882089bdf4c190b410a1c0f8516c901c766f8 /src/exchange/taler-exchange-aggregator.c
parent544fbd4fe9f536b5933467d3f1adc65a3f1b772d (diff)
downloadexchange-150917694a4dc3709319fc9586e502eb4b05151f.tar.gz
exchange-150917694a4dc3709319fc9586e502eb4b05151f.tar.bz2
exchange-150917694a4dc3709319fc9586e502eb4b05151f.zip
finish taler-exchange-drain implementation
Diffstat (limited to 'src/exchange/taler-exchange-aggregator.c')
-rw-r--r--src/exchange/taler-exchange-aggregator.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/exchange/taler-exchange-aggregator.c b/src/exchange/taler-exchange-aggregator.c
index 9568f011e..3d30ccd08 100644
--- a/src/exchange/taler-exchange-aggregator.c
+++ b/src/exchange/taler-exchange-aggregator.c
@@ -234,12 +234,12 @@ shutdown_task (void *cls)
/**
* Parse the configuration for wirewatch.
*
* @return #GNUNET_OK on success
*/
static enum GNUNET_GenericReturnValue
-parse_wirewatch_config (void)
+parse_aggregator_config (void)
{
if (GNUNET_OK !=
GNUNET_CONFIGURATION_get_value_string (cfg,
@@ -811,7 +811,7 @@ run (void *cls,
(void) cfgfile;
cfg = c;
- if (GNUNET_OK != parse_wirewatch_config ())
+ if (GNUNET_OK != parse_aggregator_config ())
{
cfg = NULL;
global_ret = EXIT_NOTCONFIGURED;
@@ -234,12 +234,12 @@ shutdown_task (void *cls)
/**
- * Parse the configuration for wirewatch.
+ * Parse the configuration for aggregator.
*
* @return #GNUNET_OK on success